summaryrefslogtreecommitdiffstats
path: root/kmail/rulewidgethandlermanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/rulewidgethandlermanager.cpp')
-rw-r--r--kmail/rulewidgethandlermanager.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/rulewidgethandlermanager.cpp b/kmail/rulewidgethandlermanager.cpp
index 42ef1ca4..9cc9e3ec 100644
--- a/kmail/rulewidgethandlermanager.cpp
+++ b/kmail/rulewidgethandlermanager.cpp
@@ -228,12 +228,12 @@ void KMail::RuleWidgetHandlerManager::unregisterHandler( const RuleWidgetHandler
}
namespace {
/** Returns the number of immediate tqchildren of tqparent with the given object
name. Used by RuleWidgetHandlerManager::createWidgets().
*/
- int childCount( const TQObject *tqparent, const char *objName )
+ int childCount( const TQObject *parent, const char *objName )
{
- TQObjectList *list = tqparent->queryList( 0, objName, false, false );
+ TQObjectList *list = parent->queryList( 0, objName, false, false );
if ( !list )
return 0;
const int count = list->count();
@@ -357,10 +357,10 @@ namespace {
// This is a simplified and constified copy of TQObject::child(). According
// to a comment in tqobject.h TQObject::child() will be made const in TQt 4.0.
// So once we require TQt 4.0 this can be removed.
- TQObject* TQObject_child_const( const TQObject *tqparent,
+ TQObject* TQObject_child_const( const TQObject *parent,
const char *objName )
{
- const TQObjectList list = tqparent->childrenListObject();
+ const TQObjectList list = parent->childrenListObject();
if ( list.isEmpty() )
return 0;
@@ -228,12 +228,12 @@ void KMail::RuleWidgetHandlerManager::unregisterHandler( const RuleWidgetHandler
}
namespace {
- /** Returns the number of immediate tqchildren of tqparent with the given object
+ /** Returns the number of immediate tqchildren of parent with the given object
name. Used by RuleWidgetHandlerManager::createWidgets().
*/